# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-04-12 14:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_digitalocean', '0004_droplet_region_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='droplet',
            name='size_name',
            field=models.CharField(blank=True, max_length=150),
        ),
    ]
